@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,16 +33,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.networkconnectivity_v1.services.hub_service import pagers
 from google.cloud.networkconnectivity_v1.types import common
 from google.cloud.networkconnectivity_v1.types import hub
 from google.cloud.networkconnectivity_v1.types import hub as gcn_hub
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import HubServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
+
 from .client import HubServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, HubServiceTransport
+from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
 
 
 class HubServiceAsyncClient:
@@ -232,13 +234,13 @@ class HubServiceAsyncClient:
     ) -> pagers.ListHubsAsyncPager:
         r"""Lists hubs in a given project.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_list_hubs():
+            async def sample_list_hubs():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.ListHubsRequest(
@@ -249,7 +251,7 @@ class HubServiceAsyncClient:
                 page_result = client.list_hubs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -310,12 +312,20 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListHubsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -332,13 +342,13 @@ class HubServiceAsyncClient:
     ) -> hub.Hub:
         r"""Gets details about the specified hub.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_get_hub():
+            async def sample_get_hub():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.GetHubRequest(
@@ -346,7 +356,7 @@ class HubServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_hub(request=request)
+                response = await client.get_hub(request=request)
 
                 # Handle the response
                 print(response)
@@ -414,7 +424,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -432,13 +447,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new hub in the specified project.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_create_hub():
+            async def sample_create_hub():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.CreateHubRequest(
@@ -451,7 +466,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -535,7 +550,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -561,14 +581,13 @@ class HubServiceAsyncClient:
         r"""Updates the description and/or labels of the
         specified hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_update_hub():
+            async def sample_update_hub():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.UpdateHubRequest(
@@ -579,7 +598,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -660,7 +679,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -684,13 +708,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified hub.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_delete_hub():
+            async def sample_delete_hub():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.DeleteHubRequest(
@@ -702,7 +726,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -775,7 +799,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -800,14 +829,13 @@ class HubServiceAsyncClient:
         r"""Lists the spokes in the specified project and
         location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_list_spokes():
+            async def sample_list_spokes():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.ListSpokesRequest(
@@ -818,7 +846,7 @@ class HubServiceAsyncClient:
                 page_result = client.list_spokes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -877,12 +905,20 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListSpokesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -899,13 +935,13 @@ class HubServiceAsyncClient:
     ) -> hub.Spoke:
         r"""Gets details about the specified spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_get_spoke():
+            async def sample_get_spoke():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.GetSpokeRequest(
@@ -913,7 +949,7 @@ class HubServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_spoke(request=request)
+                response = await client.get_spoke(request=request)
 
                 # Handle the response
                 print(response)
@@ -981,7 +1017,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1000,14 +1041,13 @@ class HubServiceAsyncClient:
         r"""Creates a spoke in the specified project and
         location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_create_spoke():
+            async def sample_create_spoke():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.CreateSpokeRequest(
@@ -1020,7 +1060,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1106,7 +1146,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1131,13 +1176,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of the specified spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_update_spoke():
+            async def sample_update_spoke():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.UpdateSpokeRequest(
@@ -1148,7 +1193,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1234,7 +1279,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1258,13 +1308,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes the specified spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
-            def sample_delete_spoke():
+            async def sample_delete_spoke():
                 # Create a client
-                client = networkconnectivity_v1.HubServiceClient()
+                client = networkconnectivity_v1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1.DeleteSpokeRequest(
@@ -1276,7 +1326,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1349,7 +1399,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
