@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,14 +36,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.networkconnectivity_v1.services.hub_service import pagers
 from google.cloud.networkconnectivity_v1.types import common
 from google.cloud.networkconnectivity_v1.types import hub
 from google.cloud.networkconnectivity_v1.types import hub as gcn_hub
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import HubServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, HubServiceTransport
 from .transports.grpc import HubServiceGrpcTransport
 from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
 
@@ -60,7 +62,10 @@ class HubServiceClientMeta(type):
     _transport_registry["grpc"] = HubServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = HubServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[HubServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[HubServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -169,10 +174,14 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def hub_path(project: str, hub: str,) -> str:
+    def hub_path(
+        project: str,
+        hub: str,
+    ) -> str:
         """Returns a fully-qualified hub string."""
         return "projects/{project}/locations/global/hubs/{hub}".format(
-            project=project, hub=hub,
+            project=project,
+            hub=hub,
         )
 
     @staticmethod
@@ -184,10 +193,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def instance_path(project: str, zone: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        zone: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/zones/{zone}/instances/{instance}".format(
-            project=project, zone=zone, instance=instance,
+            project=project,
+            zone=zone,
+            instance=instance,
         )
 
     @staticmethod
@@ -201,11 +216,15 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     @staticmethod
     def interconnect_attachment_path(
-        project: str, region: str, resource_id: str,
+        project: str,
+        region: str,
+        resource_id: str,
     ) -> str:
         """Returns a fully-qualified interconnect_attachment string."""
         return "projects/{project}/regions/{region}/interconnectAttachments/{resource_id}".format(
-            project=project, region=region, resource_id=resource_id,
+            project=project,
+            region=region,
+            resource_id=resource_id,
         )
 
     @staticmethod
@@ -218,10 +237,14 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def network_path(project: str, resource_id: str,) -> str:
+    def network_path(
+        project: str,
+        resource_id: str,
+    ) -> str:
         """Returns a fully-qualified network string."""
         return "projects/{project}/global/networks/{resource_id}".format(
-            project=project, resource_id=resource_id,
+            project=project,
+            resource_id=resource_id,
         )
 
     @staticmethod
@@ -233,10 +256,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def spoke_path(project: str, location: str, spoke: str,) -> str:
+    def spoke_path(
+        project: str,
+        location: str,
+        spoke: str,
+    ) -> str:
         """Returns a fully-qualified spoke string."""
         return "projects/{project}/locations/{location}/spokes/{spoke}".format(
-            project=project, location=location, spoke=spoke,
+            project=project,
+            location=location,
+            spoke=spoke,
         )
 
     @staticmethod
@@ -249,10 +278,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def vpn_tunnel_path(project: str, region: str, resource_id: str,) -> str:
+    def vpn_tunnel_path(
+        project: str,
+        region: str,
+        resource_id: str,
+    ) -> str:
         """Returns a fully-qualified vpn_tunnel string."""
         return "projects/{project}/regions/{region}/vpnTunnels/{resource_id}".format(
-            project=project, region=region, resource_id=resource_id,
+            project=project,
+            region=region,
+            resource_id=resource_id,
         )
 
     @staticmethod
@@ -265,7 +300,9 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -278,9 +315,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -289,9 +330,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -300,9 +345,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -311,10 +360,14 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -499,8 +552,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> pagers.ListHubsPager:
         r"""Lists hubs in a given project.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -578,12 +630,20 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListHubsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -600,8 +660,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Hub:
         r"""Gets details about the specified hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -683,7 +742,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -701,8 +765,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new hub in the specified project.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -805,7 +868,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -831,9 +899,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Updates the description and/or labels of the
         specified hub.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -931,7 +997,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -955,8 +1026,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes the specified hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1047,7 +1117,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1072,9 +1147,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Lists the spokes in the specified project and
         location.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1150,12 +1223,20 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSpokesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1172,8 +1253,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Spoke:
         r"""Gets details about the specified spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1255,7 +1335,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1274,9 +1359,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         r"""Creates a spoke in the specified project and
         location.
 
-
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1381,7 +1464,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1406,8 +1494,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of the specified spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1510,7 +1597,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1534,8 +1626,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes the specified spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1
 
@@ -1626,7 +1717,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
