@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,20 +15,19 @@
 #
 import abc
 from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
-import pkg_resources
 
-import google.auth  # type: ignore
 import google.api_core
 from google.api_core import exceptions as core_exceptions
-from google.api_core import gapic_v1
+from google.api_core import gapic_v1, operations_v1
 from google.api_core import retry as retries
-from google.api_core import operations_v1
+import google.auth  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.longrunning import operations_pb2  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 from google.cloud.networkconnectivity_v1.types import hub
 from google.cloud.networkconnectivity_v1.types import hub as gcn_hub
-from google.longrunning import operations_pb2  # type: ignore
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
@@ -83,6 +82,7 @@ class HubServiceTransport(abc.ABC):
             always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                 be used for service account credentials.
         """
+
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
         if ":" not in host:
             host += ":443"
@@ -124,43 +124,63 @@ class HubServiceTransport(abc.ABC):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
             self.list_hubs: gapic_v1.method.wrap_method(
-                self.list_hubs, default_timeout=None, client_info=client_info,
+                self.list_hubs,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_hub: gapic_v1.method.wrap_method(
-                self.get_hub, default_timeout=None, client_info=client_info,
+                self.get_hub,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_hub: gapic_v1.method.wrap_method(
-                self.create_hub, default_timeout=60.0, client_info=client_info,
+                self.create_hub,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.update_hub: gapic_v1.method.wrap_method(
-                self.update_hub, default_timeout=60.0, client_info=client_info,
+                self.update_hub,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_hub: gapic_v1.method.wrap_method(
-                self.delete_hub, default_timeout=60.0, client_info=client_info,
+                self.delete_hub,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.list_spokes: gapic_v1.method.wrap_method(
-                self.list_spokes, default_timeout=None, client_info=client_info,
+                self.list_spokes,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.get_spoke: gapic_v1.method.wrap_method(
-                self.get_spoke, default_timeout=None, client_info=client_info,
+                self.get_spoke,
+                default_timeout=None,
+                client_info=client_info,
             ),
             self.create_spoke: gapic_v1.method.wrap_method(
-                self.create_spoke, default_timeout=60.0, client_info=client_info,
+                self.create_spoke,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.update_spoke: gapic_v1.method.wrap_method(
-                self.update_spoke, default_timeout=60.0, client_info=client_info,
+                self.update_spoke,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
             self.delete_spoke: gapic_v1.method.wrap_method(
-                self.delete_spoke, default_timeout=60.0, client_info=client_info,
+                self.delete_spoke,
+                default_timeout=60.0,
+                client_info=client_info,
             ),
         }
 
     def close(self):
         """Closes resources associated with the transport.
 
-       .. warning::
-            Only call this method if the transport is NOT shared
-            with other clients - this may cause errors in other clients!
+        .. warning::
+             Only call this method if the transport is NOT shared
+             with other clients - this may cause errors in other clients!
         """
         raise NotImplementedError()
 
@@ -253,5 +273,9 @@ class HubServiceTransport(abc.ABC):
     ]:
         raise NotImplementedError()
 
+    @property
+    def kind(self) -> str:
+        raise NotImplementedError()
+
 
 __all__ = ("HubServiceTransport",)
