@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,16 +33,18 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.networkconnectivity_v1alpha1.services.hub_service import pagers
 from google.cloud.networkconnectivity_v1alpha1.types import common
 from google.cloud.networkconnectivity_v1alpha1.types import hub
 from google.cloud.networkconnectivity_v1alpha1.types import hub as gcn_hub
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import HubServiceTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
+
 from .client import HubServiceClient
+from .transports.base import DEFAULT_CLIENT_INFO, HubServiceTransport
+from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
 
 
 class HubServiceAsyncClient:
@@ -230,13 +232,13 @@ class HubServiceAsyncClient:
     ) -> pagers.ListHubsAsyncPager:
         r"""Lists Hubs in a given project and location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_list_hubs():
+            async def sample_list_hubs():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.ListHubsRequest(
@@ -247,7 +249,7 @@ class HubServiceAsyncClient:
                 page_result = client.list_hubs(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -308,12 +310,20 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListHubsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -330,13 +340,13 @@ class HubServiceAsyncClient:
     ) -> hub.Hub:
         r"""Gets details of a single Hub.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_get_hub():
+            async def sample_get_hub():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.GetHubRequest(
@@ -344,7 +354,7 @@ class HubServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_hub(request=request)
+                response = await client.get_hub(request=request)
 
                 # Handle the response
                 print(response)
@@ -410,7 +420,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -428,13 +443,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Hub in a given project and location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_create_hub():
+            async def sample_create_hub():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.CreateHubRequest(
@@ -446,7 +461,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -530,7 +545,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -555,13 +575,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Hub.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_update_hub():
+            async def sample_update_hub():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.UpdateHubRequest(
@@ -572,7 +592,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -651,7 +671,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -675,13 +700,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Hub.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_delete_hub():
+            async def sample_delete_hub():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.DeleteHubRequest(
@@ -693,7 +718,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -766,7 +791,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -790,13 +820,13 @@ class HubServiceAsyncClient:
     ) -> pagers.ListSpokesAsyncPager:
         r"""Lists Spokes in a given project and location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_list_spokes():
+            async def sample_list_spokes():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.ListSpokesRequest(
@@ -807,7 +837,7 @@ class HubServiceAsyncClient:
                 page_result = client.list_spokes(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -866,12 +896,20 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListSpokesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -888,13 +926,13 @@ class HubServiceAsyncClient:
     ) -> hub.Spoke:
         r"""Gets details of a single Spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_get_spoke():
+            async def sample_get_spoke():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.GetSpokeRequest(
@@ -902,7 +940,7 @@ class HubServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_spoke(request=request)
+                response = await client.get_spoke(request=request)
 
                 # Handle the response
                 print(response)
@@ -963,7 +1001,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -981,13 +1024,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates a new Spoke in a given project and location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_create_spoke():
+            async def sample_create_spoke():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.CreateSpokeRequest(
@@ -999,7 +1042,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1081,7 +1124,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1106,13 +1154,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Updates the parameters of a single Spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_update_spoke():
+            async def sample_update_spoke():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.UpdateSpokeRequest(
@@ -1123,7 +1171,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1203,7 +1251,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1227,13 +1280,13 @@ class HubServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes a single Spoke.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
-            def sample_delete_spoke():
+            async def sample_delete_spoke():
                 # Create a client
-                client = networkconnectivity_v1alpha1.HubServiceClient()
+                client = networkconnectivity_v1alpha1.HubServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = networkconnectivity_v1alpha1.DeleteSpokeRequest(
@@ -1245,7 +1298,7 @@ class HubServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1318,7 +1371,12 @@ class HubServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
