@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,14 +36,16 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
+
 from google.cloud.networkconnectivity_v1alpha1.services.hub_service import pagers
 from google.cloud.networkconnectivity_v1alpha1.types import common
 from google.cloud.networkconnectivity_v1alpha1.types import hub
 from google.cloud.networkconnectivity_v1alpha1.types import hub as gcn_hub
-from google.protobuf import empty_pb2  # type: ignore
-from google.protobuf import field_mask_pb2  # type: ignore
-from google.protobuf import timestamp_pb2  # type: ignore
-from .transports.base import HubServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, HubServiceTransport
 from .transports.grpc import HubServiceGrpcTransport
 from .transports.grpc_asyncio import HubServiceGrpcAsyncIOTransport
 
@@ -60,7 +62,10 @@ class HubServiceClientMeta(type):
     _transport_registry["grpc"] = HubServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = HubServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[HubServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[HubServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -169,10 +174,14 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def hub_path(project: str, hub: str,) -> str:
+    def hub_path(
+        project: str,
+        hub: str,
+    ) -> str:
         """Returns a fully-qualified hub string."""
         return "projects/{project}/locations/global/hubs/{hub}".format(
-            project=project, hub=hub,
+            project=project,
+            hub=hub,
         )
 
     @staticmethod
@@ -184,10 +193,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def instance_path(project: str, zone: str, instance: str,) -> str:
+    def instance_path(
+        project: str,
+        zone: str,
+        instance: str,
+    ) -> str:
         """Returns a fully-qualified instance string."""
         return "projects/{project}/zones/{zone}/instances/{instance}".format(
-            project=project, zone=zone, instance=instance,
+            project=project,
+            zone=zone,
+            instance=instance,
         )
 
     @staticmethod
@@ -201,11 +216,15 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
 
     @staticmethod
     def interconnect_attachment_path(
-        project: str, region: str, resource_id: str,
+        project: str,
+        region: str,
+        resource_id: str,
     ) -> str:
         """Returns a fully-qualified interconnect_attachment string."""
         return "projects/{project}/regions/{region}/interconnectAttachments/{resource_id}".format(
-            project=project, region=region, resource_id=resource_id,
+            project=project,
+            region=region,
+            resource_id=resource_id,
         )
 
     @staticmethod
@@ -218,10 +237,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def spoke_path(project: str, location: str, spoke: str,) -> str:
+    def spoke_path(
+        project: str,
+        location: str,
+        spoke: str,
+    ) -> str:
         """Returns a fully-qualified spoke string."""
         return "projects/{project}/locations/{location}/spokes/{spoke}".format(
-            project=project, location=location, spoke=spoke,
+            project=project,
+            location=location,
+            spoke=spoke,
         )
 
     @staticmethod
@@ -234,10 +259,16 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def vpn_tunnel_path(project: str, region: str, resource_id: str,) -> str:
+    def vpn_tunnel_path(
+        project: str,
+        region: str,
+        resource_id: str,
+    ) -> str:
         """Returns a fully-qualified vpn_tunnel string."""
         return "projects/{project}/regions/{region}/vpnTunnels/{resource_id}".format(
-            project=project, region=region, resource_id=resource_id,
+            project=project,
+            region=region,
+            resource_id=resource_id,
         )
 
     @staticmethod
@@ -250,7 +281,9 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -263,9 +296,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -274,9 +311,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -285,9 +326,13 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -296,10 +341,14 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -484,8 +533,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> pagers.ListHubsPager:
         r"""Lists Hubs in a given project and location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -563,12 +611,20 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListHubsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -585,8 +641,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Hub:
         r"""Gets details of a single Hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -666,7 +721,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -684,8 +744,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new Hub in a given project and location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -787,7 +846,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -812,8 +876,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -909,7 +972,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -933,8 +1001,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Hub.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1025,7 +1092,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1049,8 +1121,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> pagers.ListSpokesPager:
         r"""Lists Spokes in a given project and location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1126,12 +1197,20 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListSpokesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1148,8 +1227,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> hub.Spoke:
         r"""Gets details of a single Spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1224,7 +1302,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1242,8 +1325,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Creates a new Spoke in a given project and location.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1343,7 +1425,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1368,8 +1455,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Updates the parameters of a single Spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1466,7 +1552,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1490,8 +1581,7 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
     ) -> operation.Operation:
         r"""Deletes a single Spoke.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import networkconnectivity_v1alpha1
 
@@ -1582,7 +1672,12 @@ class HubServiceClient(metaclass=HubServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
