@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,11 +13,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-import proto  # type: ignore
-
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
-
+import proto  # type: ignore
 
 __protobuf__ = proto.module(
     package="google.cloud.networkconnectivity.v1alpha1",
@@ -66,7 +64,7 @@ class Hub(proto.Message):
             Time when the Hub was created.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Time when the Hub was updated.
-        labels (Sequence[google.cloud.networkconnectivity_v1alpha1.types.Hub.LabelsEntry]):
+        labels (Mapping[str, str]):
             User-defined labels.
         description (str):
             Short description of the hub resource.
@@ -83,14 +81,42 @@ class Hub(proto.Message):
             this Hub.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    description = proto.Field(proto.STRING, number=5,)
-    spokes = proto.RepeatedField(proto.STRING, number=6,)
-    unique_id = proto.Field(proto.STRING, number=8,)
-    state = proto.Field(proto.ENUM, number=9, enum="State",)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    spokes = proto.RepeatedField(
+        proto.STRING,
+        number=6,
+    )
+    unique_id = proto.Field(
+        proto.STRING,
+        number=8,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=9,
+        enum="State",
+    )
 
 
 class Spoke(proto.Message):
@@ -105,7 +131,7 @@ class Spoke(proto.Message):
             The time when the Spoke was created.
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             The time when the Spoke was updated.
-        labels (Sequence[google.cloud.networkconnectivity_v1alpha1.types.Spoke.LabelsEntry]):
+        labels (Mapping[str, str]):
             User-defined labels.
         description (str):
             Short description of the spoke resource
@@ -129,19 +155,55 @@ class Spoke(proto.Message):
             this Hub.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    create_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
-    update_time = proto.Field(proto.MESSAGE, number=3, message=timestamp_pb2.Timestamp,)
-    labels = proto.MapField(proto.STRING, proto.STRING, number=4,)
-    description = proto.Field(proto.STRING, number=5,)
-    hub = proto.Field(proto.STRING, number=6,)
-    linked_vpn_tunnels = proto.RepeatedField(proto.STRING, number=12,)
-    linked_interconnect_attachments = proto.RepeatedField(proto.STRING, number=13,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    create_time = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message=timestamp_pb2.Timestamp,
+    )
+    labels = proto.MapField(
+        proto.STRING,
+        proto.STRING,
+        number=4,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=5,
+    )
+    hub = proto.Field(
+        proto.STRING,
+        number=6,
+    )
+    linked_vpn_tunnels = proto.RepeatedField(
+        proto.STRING,
+        number=12,
+    )
+    linked_interconnect_attachments = proto.RepeatedField(
+        proto.STRING,
+        number=13,
+    )
     linked_router_appliance_instances = proto.RepeatedField(
-        proto.MESSAGE, number=14, message="RouterApplianceInstance",
+        proto.MESSAGE,
+        number=14,
+        message="RouterApplianceInstance",
+    )
+    unique_id = proto.Field(
+        proto.STRING,
+        number=11,
+    )
+    state = proto.Field(
+        proto.ENUM,
+        number=15,
+        enum="State",
     )
-    unique_id = proto.Field(proto.STRING, number=11,)
-    state = proto.Field(proto.ENUM, number=15, enum="State",)
 
 
 class ListHubsRequest(proto.Message):
@@ -164,11 +226,26 @@ class ListHubsRequest(proto.Message):
             Sort the results by a certain order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListHubsResponse(proto.Message):
@@ -191,9 +268,19 @@ class ListHubsResponse(proto.Message):
     def raw_page(self):
         return self
 
-    hubs = proto.RepeatedField(proto.MESSAGE, number=1, message="Hub",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    hubs = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Hub",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetHubRequest(proto.Message):
@@ -206,7 +293,10 @@ class GetHubRequest(proto.Message):
             Required. Name of the Hub resource to get.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateHubRequest(proto.Message):
@@ -242,10 +332,23 @@ class CreateHubRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    hub_id = proto.Field(proto.STRING, number=2,)
-    hub = proto.Field(proto.MESSAGE, number=3, message="Hub",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    hub_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    hub = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Hub",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateHubRequest(proto.Message):
@@ -285,10 +388,19 @@ class UpdateHubRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    hub = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Hub",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    hub = proto.Field(proto.MESSAGE, number=2, message="Hub",)
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteHubRequest(proto.Message):
@@ -318,8 +430,14 @@ class DeleteHubRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class ListSpokesRequest(proto.Message):
@@ -341,11 +459,26 @@ class ListSpokesRequest(proto.Message):
             Sort the results by a certain order.
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    page_size = proto.Field(proto.INT32, number=2,)
-    page_token = proto.Field(proto.STRING, number=3,)
-    filter = proto.Field(proto.STRING, number=4,)
-    order_by = proto.Field(proto.STRING, number=5,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    page_size = proto.Field(
+        proto.INT32,
+        number=2,
+    )
+    page_token = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    filter = proto.Field(
+        proto.STRING,
+        number=4,
+    )
+    order_by = proto.Field(
+        proto.STRING,
+        number=5,
+    )
 
 
 class ListSpokesResponse(proto.Message):
@@ -367,9 +500,19 @@ class ListSpokesResponse(proto.Message):
     def raw_page(self):
         return self
 
-    spokes = proto.RepeatedField(proto.MESSAGE, number=1, message="Spoke",)
-    next_page_token = proto.Field(proto.STRING, number=2,)
-    unreachable = proto.RepeatedField(proto.STRING, number=3,)
+    spokes = proto.RepeatedField(
+        proto.MESSAGE,
+        number=1,
+        message="Spoke",
+    )
+    next_page_token = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    unreachable = proto.RepeatedField(
+        proto.STRING,
+        number=3,
+    )
 
 
 class GetSpokeRequest(proto.Message):
@@ -381,7 +524,10 @@ class GetSpokeRequest(proto.Message):
             Required. The name of Spoke resource.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class CreateSpokeRequest(proto.Message):
@@ -416,10 +562,23 @@ class CreateSpokeRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    parent = proto.Field(proto.STRING, number=1,)
-    spoke_id = proto.Field(proto.STRING, number=2,)
-    spoke = proto.Field(proto.MESSAGE, number=3, message="Spoke",)
-    request_id = proto.Field(proto.STRING, number=4,)
+    parent = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    spoke_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
+    spoke = proto.Field(
+        proto.MESSAGE,
+        number=3,
+        message="Spoke",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=4,
+    )
 
 
 class UpdateSpokeRequest(proto.Message):
@@ -459,10 +618,19 @@ class UpdateSpokeRequest(proto.Message):
     """
 
     update_mask = proto.Field(
-        proto.MESSAGE, number=1, message=field_mask_pb2.FieldMask,
+        proto.MESSAGE,
+        number=1,
+        message=field_mask_pb2.FieldMask,
+    )
+    spoke = proto.Field(
+        proto.MESSAGE,
+        number=2,
+        message="Spoke",
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    spoke = proto.Field(proto.MESSAGE, number=2, message="Spoke",)
-    request_id = proto.Field(proto.STRING, number=3,)
 
 
 class DeleteSpokeRequest(proto.Message):
@@ -492,8 +660,14 @@ class DeleteSpokeRequest(proto.Message):
             (00000000-0000-0000-0000-000000000000).
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    request_id = proto.Field(proto.STRING, number=2,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    request_id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 class RouterApplianceInstance(proto.Message):
@@ -510,9 +684,18 @@ class RouterApplianceInstance(proto.Message):
 
     """
 
-    virtual_machine = proto.Field(proto.STRING, number=1,)
-    ip_address = proto.Field(proto.STRING, number=3,)
-    network_interface = proto.Field(proto.STRING, number=2,)
+    virtual_machine = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    ip_address = proto.Field(
+        proto.STRING,
+        number=3,
+    )
+    network_interface = proto.Field(
+        proto.STRING,
+        number=2,
+    )
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
